@@ -17,10 +17,10 @@
 
    You should have received a copy of the GNU General Public License
    along with Zile; see the file COPYING.  If not, write to the Free
-   Software Foundation, 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA.  */
+   Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
+   02111-1301, USA.  */
 
-/*	$Id: zmalloc.c,v 1.1 2004/11/15 00:47:12 rrt Exp $	*/
+/*	$Id: zmalloc.c,v 1.4 2005/07/11 06:10:26 rrt Exp $	*/
 
 
 #include "config.h"
@@ -37,16 +37,16 @@
  */
 void *zmalloc(size_t size)
 {
-	void *ptr;
+  void *ptr;
 
-	assert(size > 0);
+  assert(size > 0);
 
-	if ((ptr = calloc(size, 1)) == NULL) {
-		fprintf(stderr, "zile: cannot allocate memory\n");
-		zile_exit(1);
-	}
+  if ((ptr = calloc(size, 1)) == NULL) {
+    fprintf(stderr, "zile: cannot allocate memory\n");
+    zile_exit(1);
+  }
 
-	return ptr;
+  return ptr;
 }
 
 /*
@@ -54,16 +54,16 @@ void *zmalloc(size_t size)
  */
 void *zrealloc(void *ptr, size_t size)
 {
-	void *newptr;
+  void *newptr;
 
-	assert(size > 0);
+  assert(size > 0);
 
-	if ((newptr = realloc(ptr, size)) == NULL) {
-		fprintf(stderr, "zile: cannot allocate memory\n");
-		zile_exit(1);
-	}
+  if ((newptr = realloc(ptr, size)) == NULL) {
+    fprintf(stderr, "zile: cannot reallocate memory\n");
+    zile_exit(1);
+  }
 
-	return newptr;
+  return newptr;
 }
 
 /*
@@ -71,5 +71,35 @@ void *zrealloc(void *ptr, size_t size)
  */
 char *zstrdup(const char *s)
 {
-	return strcpy(zmalloc(strlen(s) + 1), s);
+  return strcpy(zmalloc(strlen(s) + 1), s);
+}
+
+/*
+ * Wrapper for vasprintf.
+ */
+int zvasprintf(char **ptr, const char *fmt, va_list vargs)
+{
+  int retval = vasprintf(ptr, fmt, vargs);
+
+  if (retval == -1) {
+    fprintf(stderr, "zile: cannot allocate memory for asprintf\n");
+    zile_exit(1);
+  }
+
+  return retval;
+}
+
+/*
+ * Wrapper for asprintf.
+ */
+int zasprintf(char **ptr, const char *fmt, ...)
+{
+  va_list vargs;
+  int retval;
+
+  va_start(vargs, fmt);
+  retval = zvasprintf(ptr, fmt, vargs);
+  va_end(vargs);
+
+  return retval;
 }
